@@ -19,7 +19,7 @@ Readonly my $IDX4                         => 4;
 Readonly our $ISPAPI_CONNECTION_URL       => 'https://api.ispapi.net/api/call.cgi';    # Default Connection Setup URL
 Readonly our $ISPAPI_CONNECTION_URL_PROXY => 'http://127.0.0.1/api/call.cgi';          # High Speed Connection Setup URL
 
-use version 0.9917; our $VERSION = version->declare('v2.5.0');
+use version 0.9917; our $VERSION = version->declare('v2.6.1');
 
 my $rtm = WebService::Hexonet::Connector::ResponseTemplateManager->getInstance();
 
@@ -283,6 +283,7 @@ sub request {
     $newcmd = $self->_autoIDNConvert($newcmd);
 
     # request command to API
+    my $cfg = { CONNECTION_URL => $self->{socketURL} };
     my $data = $self->getPOSTData($newcmd);
 
     my $ua = LWP::UserAgent->new();
@@ -299,7 +300,7 @@ sub request {
     }
 
     my $post = $self->getPOSTData($cmd);
-    my $r = $ua->post( $self->{socketURL}, $post );
+    my $r = $ua->post( $cfg->{CONNECTION_URL}, $post );
     if ( $r->is_success ) {
         $r = $r->decoded_content;
         if ( $self->{debugMode} ) {
@@ -316,7 +317,7 @@ sub request {
             print {*STDERR} Dumper($r);
         }
     }
-    return WebService::Hexonet::Connector::Response->new( $r, $newcmd );
+    return WebService::Hexonet::Connector::Response->new( $r, $newcmd, $cfg );
 }
 
 
