@@ -4,7 +4,7 @@ use 5.026_000;
 use strict;
 use warnings;
 
-use version 0.9917; our $VERSION = version->declare('v2.5.0');
+use version 0.9917; our $VERSION = version->declare('v2.6.1');
 
 
 sub parse {
@@ -32,9 +32,6 @@ sub parse {
             }
         }
     }
-    if ( !defined $hash{DESCRIPTION} ) {
-        $hash{DESCRIPTION} = q{};
-    }
     return \%hash;
 }
 
